@@ -11,7 +11,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Tiny::AUTHORITY   = 'cpan:TOBYINK';
-	$Type::Tiny::VERSION     = '1.007_002';
+	$Type::Tiny::VERSION     = '1.007_004';
 	$Type::Tiny::XS_VERSION  = '0.011';
 }
 
@@ -1284,7 +1284,8 @@ sub AUTOLOAD
 	if ($self->{is_object} && $object_methods{$m}) {
 		require Type::Tiny::ConstrainedObject;
 		unshift @_, $self;
-		goto( Type::Tiny::ConstrainedObject->can($m) );
+		no strict 'refs';
+		goto \&{"Type::Tiny::ConstrainedObject::$m"};
 	}
 	
 	_croak q[Can't locate object method "%s" via package "%s"], $m, ref($self)||$self;
@@ -2147,11 +2148,6 @@ of parts of Type::Tiny.
 Please report any bugs to
 L<http://rt.cpan.org/Dist/Display.html?Queue=Type-Tiny>.
 
-=head1 SUPPORT
-
-B<< IRC: >> support is available through in the I<< #moops >> channel
-on L<irc.perl.org|http://www.irc.perl.org/channels.html>.
-
 =head1 SEE ALSO
 
 L<Type::Tiny::Manual>, L<Type::API>.
